package org.xdv.clx.builder;

import org.w3c.dom.Node;

/**
 * Helper to access elements/attributes in W3C DOM XML document.
 * It contains set of methods that are useful when creating CLiXML rule from 
 * W3C DOM XML source (see {@link ClxDOMBuilder}).
 * <p>
 * Helper is always associated with namespace.  
 * This particular version can be associated with any given namespace URI.
 * <br>
 * There is another version of helper that works with <i>empty</i> namepsace
 * - {@link org.xdv.clx.builder.ClxDOMHelper}.  
 * </p>
 * <p>
 * To create an instance call {@link #newInstance(String)}.
 * </p>
 *
 * @author Tomasz Kokoszka
 */

public class ClxDOMHelperNS extends ClxDOMHelper  {
    
    /**
     * Returns instance of helper that works with any given namepsace URL.
     * @param namespaceURI namespace URI
     * @return a helper to work with given namespace
     */
    public static ClxDOMHelperNS newInstance(String namespaceURI) {
        return new ClxDOMHelperNS(namespaceURI);
    }
    
    /** Helper's namespace; !=null */
    private final String nsURI;
    
    /**
     * Creates new instance.
     * @param namespaceURI namespace URI
     */
    protected ClxDOMHelperNS(String namespaceURI) {
        this.nsURI = namespaceURI;
    }
    
    public boolean isNS(String namespaceURI) {
        return nsURI.equals(namespaceURI);
    }
    
    public String getNodeName(Node node) {
        return node.getLocalName();
    }

    protected String getNS() {
        return this.nsURI;
    }
    
}
