package org.xdv.clx.expr;

import org.xdv.clx.exec.ClxExecutionPoint;

/**
 * Binary operator - a general CLX type.
 * It consist of exacly two sub-formulas (order is important).
 *
 * @see <a href="http://www.clixml.org/clix/1.0/docs/html/#complexType_BinaryOperatorType_Link036E0268">CliXML BinaryOperatorType</a> 
 * @author Tomasz Kokoszka
 */
public abstract class ClxFormulaBinaryOperator implements ClxFormula {
    
    /**
     * Internal class to store execution state - to resume execution in
     * {@link ClxFormula#executeFormula(org.xdv.clx.exec.ClxExecutionContext, ClxExecutionPoint)}.
     * @author Tomasz Kokoszka
     */
    protected static class State {
        /** Result of first sub-formula */
        public boolean v1;
        /** Result of secound sub-formula */        
        public boolean v2;
    }
    
    /** First sub-formula; !=null */
    private final ClxFormula formula1;
    
    /** Secound sub-formula; !=null */
    private final ClxFormula formula2;
    
    /**
     * Creates an instance.
     * @param formula1 first sub-formula
     * @param formula2 secound sub-formula
     */
    public ClxFormulaBinaryOperator(ClxFormula formula1, ClxFormula formula2) {
        super();
        this.formula1 = formula1;
        this.formula2 = formula2;
    }

    /** 
     * Returns first sub-formula.
     * @return first sub-formula; !=null
     */
    public ClxFormula getFormula1() {
        return formula1;
    }

    /** 
     * Returns secound sub-formula.
     * @return secound sub-formula; !=null
     */
    public ClxFormula getFormula2() {
        return formula2;
    }
    
    /**
     * Returns execution state from execution point.
     * If given execution point doesn't stores a valid state then a new one is created and 
     * added into to execution point.
     * @param frame execution point
     * @return execution state; !=null
     */
    protected State getExecutionState(ClxExecutionPoint frame) {
        State s = (State) frame.getData();
        if (s == null) {
            s = new State();
            frame.setData(s);
        }
        return s;
    }

}
