package org.xdv.clx.expr;

import java.util.Iterator;
import java.util.Set;

/**
 * MACRO - CLX element implementation.
 * <br>
 * It is a definition of a single macro.
 * 
 * @see <a href="http://www.clixml.org/clix/1.0/docs/html/#element_macro_Link01B655E8">CLiXML - macro</a>
 * @see org.xdv.clx.base.ClxConstants#TAG_MACRO
 * @author Tomasz Kokoszka
 */
public class ClxMacro {
   
    /** Macro's name; !=null */
    private final String name;
    
    /** Header, null means no header */
    private final ClxHeader header;
    
    /** Macro parameter names - set of {@link String}; !=null */
    private final Set params;
    
    /** Macro output - formula */
    private final ClxFormula output;

    /**
     * Create macro.
     * @param name macro's name 
     * @param params macro parameter names - set of {@link String}
     * @param output macro output - formula
     * @param header header, can be null
     */
    public ClxMacro(String name, Set params, ClxFormula output, ClxHeader header) {
        this.name = name;
        this.header = header;
        this.params = params;
        this.output = output;
    }

    /**
     * Returns macro name.
     * @return macro name; !=null;
     */
    public String getName() {
        return this.name;
    }

    /**
     * Returns header.
     * @return header, null means there is no header
     */
    public ClxHeader getHeader() {
        return this.header;
    }

    /**
     * Returns macro output - formula.
     * @return output/formula; !=null
     */
    public ClxFormula getOutput() {
        return this.output;
    }

    /**
     * Returns macro parameter names.
     * @return set of {@link String}; !=null
     */
    public Set getParams() {
        return this.params;
    }
    
    public String toString() {
        StringBuffer sb = new StringBuffer();
        sb.append(name).append("(");
        for(Iterator i = params.iterator(); i.hasNext(); ) {
            sb.append(i.next());
            if (i.hasNext()) {
                sb.append(", ");
            }
        }
        sb.append(")");
        sb.append("{").append(output).append("}");
        
        return sb.toString();        
    }

}
