package org.xdv.clx.expr;

import org.xdv.xpath.XPathExpression;

/**
 * RULES/VARIABLE - CLX element implementation.
 * <br>
 * It is kind of global variable accesible in all formulas unside one rule set.
 * 
 * @see <a href="http://www.clixml.org/clix/1.0/#rules.schema">CLiXML - clix:variable</a>
 * @see org.xdv.clx.base.ClxConstants#TAG_VARIABLE
 * @author Tomasz Kokoszka
 */
public class ClxVariable {

    /** Variable id/name */
    private final String id;
    
    /** Expression to evaluate variable value */
    private final XPathExpression xpath;
    
    /** 
     * Create variable.
     * @param id variable name
     * @param xpath expression to evaluate variable value
     */
    public ClxVariable(String id, XPathExpression xpath) {
        super();
        this.id = id;
        this.xpath = xpath;
    }        
    
    /**
     * Returns variable id/name.
     * @return variable id/name; !=null
     */
    public String getId() {
        return id;
    }

    /**
     * Returns expression to evaluate variable value.
     * @return expression to evaluate variable value; !=null
     */
    public XPathExpression getXpath() {
        return xpath;
    }
    
    public String toString() {
        return this.id;
    }
    
}
